@@ -5,9 +5,9 @@
 ;; Author: Julien Dallot <judafa@protonmail.com>
 ;; Maintainer: Julien Dallot <judafa@protonmail.com>
 ;; URL: https://github.com/Judafa/linkin-org
-;; Package-Version: 20251017.839
-;; Package-Revision: 92f39cf41412
-;; Package-Requires: ((emacs "30.1") (s "1.30.0") (dash "2.20.0"))
+;; Package-Version: 20251116.1638
+;; Package-Revision: 1ce63411cc48
+;; Package-Requires: ((emacs "30.1"))
 
 ;; This file is not part of GNU Emacs
 
@@ -33,7 +33,6 @@
 (require 'ol)
 (require 'org)
 (require 'org-element-ast)
-(require 'dash)
 (require 'dired)
 
 
@@ -81,7 +80,7 @@
 
 ;; List of link types such that, if the link is broken, the ids in the link are used to resolve the link
 (defcustom linkin-org-link-types-to-check-for-id
-  '("file" "pdf")
+  '("file" "pdf" "nov")
   "List of link types such that their path is resolved when opened."
   :type '(string)
   :group 'linkin-org)
@@ -213,15 +212,23 @@ Also strip off the separator -- if possible."
      ""
      file-name))))
 
-(defun linkin-org-give-id-to-file-name (file-name &optional is-directory-p)
+(defun linkin-org-give-id-to-file-name (file-name &optional is-directory-p id)
   "Insert an id into FILE-NAME.
 If IS-DIRECTORY-P is non-nil, then insert an id as if FILE-NAME is a directory.
-Does not add an id if FILE-NAME already has one."
+Does not add an id if FILE-NAME already has one.
+If ID is non nil and matches an id syntax, use it as an id"
   (if (linkin-org-extract-id file-name)
       ;; if the file already has an id, dont add one
       file-name
     ;; else add an id
-    (if (eq linkin-org-id-position-in-file-name 'tail)
+    (let*
+	;; if an id was provided as argument then use it, else create a new one
+	((file-id (if (linkin-org-extract-id id)
+		      id
+		    (linkin-org-create-id)
+		    )
+		  ))
+     (if (eq linkin-org-id-position-in-file-name 'tail)
 	;; if we must add the id at the tail of the file name
 	(if (not is-directory-p)
 	    ;; if file-name is not a directory, then insert the id before the extension (eg, .txt)
@@ -231,13 +238,13 @@ Does not add an id if FILE-NAME already has one."
 	       (? (seq "." (zero-or-more (not "."))))
 	       line-end))
 	     (lambda (match)
-	       (concat linkin-org-sep (linkin-org-create-id) match))
+	       (concat linkin-org-sep file-id match))
 	     file-name)
 	  ;; else if this file-name is a directory name, just insert the id at the end
-	  (concat file-name linkin-org-sep (linkin-org-create-id))
+	  (concat file-name linkin-org-sep file-id)
 	  )
       ;; else just add the id at the head of the file name
-      (concat (linkin-org-create-id) linkin-org-sep file-name))))
+      (concat file-id linkin-org-sep file-name)))))
 
 (defun linkin-org-escape-square-brackets (str)
   "Escape occurrences of '\\\\', '\\[', and '\\]' in the string STR."
@@ -358,7 +365,7 @@ It is assumed you already checked that FILE-PATH is not a valid path."
 		  ;; else, just use emacs-lisp code to find a matching id. slowest option
 		  (setq building-dir
 			(car
-			 (-filter
+			 (seq-filter
 			  (lambda (s)
 			    (or
 			     (not (string-equal s "."))
@@ -462,7 +469,7 @@ It is assumed you already checked that FILE-PATH is not a valid path before."
 	   (t
 	    (setq resolved-file-path
 		  (car
-		   (-filter
+		   (seq-filter
 		    ;; get rid of the "." and ".." files
 		    (lambda (s)
 		      (or
@@ -956,7 +963,18 @@ Do nothing if the file already has an id."
    ((not buffer-read-only)
     (let ((inline-link (linkin-org-get-inline)))
       ;; copy the link only if a non-nil link was computed
-      (when inline-link (kill-new (linkin-org-get-inline)))))))
+      (when inline-link (kill-new (linkin-org-get-inline)))))
+
+   ;; otherwise, call the standard org-store-link function and put the created link in kill ring
+   (t
+    (let ((inhibit-message t))
+     (call-interactively 'org-store-link)
+     )
+    (let
+	((path (caar org-stored-links))
+	 (description (cadr (car org-stored-links))))
+      (kill-new (concat "[[" path "][" description "]]"))
+      ))))
 
 
 
@@ -1095,7 +1113,22 @@ Otherwise, calls the function STD-LINK-OPENING-FUNCTION to open it."
 	;; open the link as in Dired if it's a file link and if the user wants to
 	(linkin-org-file-open link)
       ;; else call the standard link opening function
-      (funcall std-link-opening-function link link))))
+      (let ((metadata (org-element-property :metadata link)))
+	;; if the metadata of the link is not a plist, means that it was not generated by linkin-org, so add it back to the link
+	(unless (plistp metadata)
+	  (org-element-put-property link :path (concat
+						 (org-element-property :path link)
+						 "::"
+						 (prin1-to-string metadata))))
+	(funcall std-link-opening-function link link)
+
+       ;; let (
+       ;; 	    (metadata (prin1-to-string (org-element-property :metadata link)))
+       ;; 	    (link (if (not (plistp metadata))))
+       ;; 	    )
+       ;; 	(funcall std-link-opening-function link link)
+       ;; 	)
+      ))))
 
 ;;;###autoload
 (define-minor-mode linkin-org-mode
